[![Build Status](https://travis-ci.com/cmccandless/easy_getch.svg?branch=master)](https://travis-ci.com/cmccandless/easy_getch)[![PyPI](https://img.shields.io/pypi/v/nine.svg)](https://pypi.org/project/easy_getch/)

# easy-getch
Easily get a single character.

Inspired by [this article](https://code.activestate.com/recipes/134892).

## Installation
```bash
pip install easy_getch
```

## Usage

```Python
from easy_getch import getch

ch = getch()
print(ch)
```
